@@ -1,15 +1,14 @@
 import logging
-from typing import Dict
 
 import httpx
 
-from .exceptions import ApiClientException
+from .exceptions import JelasticClientException
 
 
 def compute_function_endpoint(two_dotted_function_name: str):
     uri_chunks = two_dotted_function_name.split(".")
     if len(uri_chunks) != 3:
-        raise ApiClientException(
+        raise JelasticClientException(
             f"Function ({two_dotted_function_name}) doesn't match standard Jelastic function (Group.Class.Function)"
         )
     grp = uri_chunks[0]
@@ -31,7 +30,7 @@ class ApiClient:
         # the jelastic api is _synchronous_ => no timeouts
         self.client = httpx.Client(timeout=None)
 
-    def _apicall(self, uri: str, method: str, data: dict = {}) -> Dict:
+    def _apicall(self, uri: str, method: str, data: dict = {}) -> dict:
         """
         Lowest-level API call: that's the method that talks over the network to the Jelastic API
         """
@@ -41,19 +40,20 @@ class ApiClient:
             method=method, url=f"{self.api_url.strip('/')}/{uri}", data=data
         )
         if r.status_code != httpx.codes.OK:
-            raise ApiClientException(
+            raise JelasticClientException(
                 f"{method} to {uri} failed with HTTP code {r.status_code}"
             )
 
         response = r.json()
         if response["result"] != 0:
-            raise ApiClientException(
-                f"{method} to {uri} returned non-zero result", response
+            raise JelasticClientException(
+                f"{method} to {uri} returned non-zero result: {response['error']}",
+                response,
             )
         self.logger.debug(f"response : {response}")
         return response
 
-    def execute(self, function: str, **kwargs) -> Dict:
+    def execute(self, function: str, **kwargs) -> dict:
         """
         Direct API call, converting function paths into URLs; allows:
             api_client.execute('Environment.Control.GetEnvs')
